.. bookstore documentation master file, created by
   sphinx-quickstart on Mon Oct 22 20:40:04 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

bookstore
=========

Release v\ |release| (:doc:`What's new? <changelog>`).

**bookstore** provides tooling and workflow recommendations for storing, scheduling, and publishing notebooks.


Table of Contents
=================

.. toctree::
   :maxdepth: 2

   installation
   configuration
   usage
   openapi
   reference/index
   project/index
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
